package com.ruoyi.change.mapper;

import java.util.List;
import com.ruoyi.change.domain.TbAssetAllocationDetail;

/**
 * 资产调拨明细Mapper接口
 * 
 * @author 原动力
 * @date 2023-05-15
 */
public interface TbAssetAllocationDetailMapper 
{
    /**
     * 查询资产调拨明细
     * 
     * @param id 资产调拨明细主键
     * @return 资产调拨明细
     */
    public TbAssetAllocationDetail selectTbAssetAllocationDetailById(Long id);

    /**
     * 查询资产调拨明细列表
     * 
     * @param tbAssetAllocationDetail 资产调拨明细
     * @return 资产调拨明细集合
     */
    public List<TbAssetAllocationDetail> selectTbAssetAllocationDetailList(TbAssetAllocationDetail tbAssetAllocationDetail);

    /**
     * 新增资产调拨明细
     * 
     * @param tbAssetAllocationDetail 资产调拨明细
     * @return 结果
     */
    public int insertTbAssetAllocationDetail(TbAssetAllocationDetail tbAssetAllocationDetail);

    /**
     * 修改资产调拨明细
     * 
     * @param tbAssetAllocationDetail 资产调拨明细
     * @return 结果
     */
    public int updateTbAssetAllocationDetail(TbAssetAllocationDetail tbAssetAllocationDetail);

    /**
     * 删除资产调拨明细
     * 
     * @param id 资产调拨明细主键
     * @return 结果
     */
    public int deleteTbAssetAllocationDetailById(Long id);

    /**
     * 批量删除资产调拨明细
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbAssetAllocationDetailByIds(Long[] ids);
}
